<?php
/**
 * FlickrImport
 *
 * Import your flickr stream into your pixelpost stream.
 *
 * IMPORTANT :
 *
 * This Pixelpost Addon include a modified part of Phlickr
 * produced by Andrew Morton <drewish@katherinehouse.com>
 * (@link http://sourceforge.net/projects/phlickr/)
 * which is under LGPL license.
 *
 * This Pixelpost addon is heavily inspired by Pixelpost Importr addon produced
 * by Christian Cueni <chrigu@trivialview.ch> (@link http://www.trivialview.ch)
 * which is under GPL license.
 *
 * REQUIREMENTS :
 * 
 * - PHP CURL library installed
 * - SimpleXml library installed
 *
 * LICENCE :
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 *
 * @version 0.03
 * @author Alban Leroux <seza@paradoxal.org>
 * @see http://www.paradoxal.org/blog/
 * @license GPL License: http://www.gnu.org/copyleft/gpl.html
 */

//includes
require_once '../../includes/functions.php';
require_once '../../includes/pixelpost.php';
require_once '../../includes/exifer1_5/exif.php';
require_once '../../includes/functions_exif.php';
require_once './common.php';

// register the phlickr library
FlickrImport::registerPhlickrLibrary();

// connect to databse
FlickrImport::mysqlConnect();

// Photos flickr's id table
FlickrImport::isInstalled() or FlickrImport::install();

// Check for update
FlickrImport::makeUpdate();

// get the User configuration
$conf = FlickrImport::getOptions();

// get the correct endLine
$endLine = FlickrImport::getEndLine();

// load the flick API
$api = FlickrImport::getApi($conf['token']);

// load the photoset to sync
$sync  = FlickrImport::getSyncPhotoset();
$notag = FlickrImport::getNotSyncTags();

// get the image path configuration
$req = FlickrImport::mysqlQuery('select `imagepath`, `thumbnailpath` from `%sconfig`;');

$result = mysql_fetch_assoc($req);

//Paths
$imagePath = rtrim($result['imagepath'], '/');
$thumbPath = rtrim($result['thumbnailpath'], '/');

if ($imagePath{0} != '/')
{
    $imagePath = realpath(dirname(__FILE__) . '/../' . $imagePath);
}

if ($thumbPath{0} != '/')
{
    $thumbPath = realpath(dirname(__FILE__) . '/../' . $thumbPath);
}

$imagePath .= '/';
$thumbPath .= '/';

// check if authentificated
if ( ! $api->isAuthValid() )
{
    exit('Fail to connect, please use a valid key, secret configuration !');
}

// retreive user_id information
try
{
    $user = new Phlickr_User($api, $api->getUserId());
}
catch(Exception $e)
{
    exit('Fail to connect at ' . $api->getUserId() . ' this user doesn\'t exist !');
}

// start sync
echo 'Retreive photo stream of ' . $user->getName() . ' at '
                                 . $user->buildUrl() . '.' . $endLine . $endLine;

// get all user's photoset and register photo
foreach($user->getPhotosetList()->getPhotosets() as $photoset)
{
    // if photoset is not in the sync list, go to the next photoset
    if ( ! isset($sync[$photoset->getId()]) ) continue;

    echo 'Check if photoset ' . $photoset->getTitle() . ' exists... ';

    flush();

    // check if the photoset is registred in pixelpost
    if (FlickrImport::isPhotoset($photoset->getId()))
    {
        echo 'Yes !' . $endLine;
    }
    else
    {
        echo 'No, register it !' . $endLine;

        FlickrImport::addPhotoset($photoset->getId(), $photoset->getTitle(), $photoset->getDescription());
    }

    echo 'Retreive ' . $photoset->getPhotoCount() . ' photo(s) of '
                     . $photoset->getTitle() . ' photoset.' . $endLine . $endLine;

    // each photo of the photo set
    foreach($photoset->getPhotoList()->getPhotos() as $photo)
    {
        // max 30 seconds by photo
        set_time_limit(30);

        echo 'Check if photo ' . $photo->getId() . ' exists... ';

        // if the photo is allready imported
        if (FlickrImport::isPhoto($photo->getId()))
        {
            echo 'Yes !' . $endLine;
        }
        else
        {
            // import the photo
            echo 'No, register it !' . $endLine;

            // get the photo infos
            $tags = $photo->getTags();
            $head = $photo->getTitle();
            $body = $photo->getDescription();
            $size = $photo->getSizes();
            $post = $photo->getPostedDate();
            $date = $photo->getTakenDate();
            $link = $photo->buildUrl();

            // check the tag configuration
            if ($conf['photo.tags'] == 'yes')
            {
                $listTag = '';

                foreach($tags as $tag)
                {
                    // if the tag is in blacklist go to the next tag
                    if (isset($notag[$tag])) continue;

                    $listTag .= ' ' . $tag;
                }

                $tags = ltrim($listTag);
            }
            else
            {
                $tags = '';
            }

            // create the photo filename
            $filename = 'Flickr-'
                      . str_replace(array('-', ':', ' '), array('', '', ''), $post)
                      . '-'
                      . $photo->getId()
                      . '.'
                      . $size[Phlickr_Photo::SIZE_ORIGINAL]['type'];

            // download the photo with the prefered size
            if ($conf['photo.size'] == '1024' && isset($size['b']))
            {
                $photo->saveAs($imagePath . $filename, Phlickr_Photo::SIZE_1024PX, $size['b']['source']);
            }
            elseif ($conf['photo.size'] == '500' && isset($size['-']))
            {
                $photo->saveAs($imagePath . $filename, Phlickr_Photo::SIZE_500PX, $size['-']['source']);
            }
            else
            {
                $photo->saveAs($imagePath . $filename, Phlickr_Photo::SIZE_ORIGINAL);
            }

            // retreive the photo exif data before potential resizing which
            // the cause lost of data
            $exif = serialize_exif($imagePath . $filename);

            // check if photo need resize
            if ($conf['photo.resize'] == 'yes')
            {
                echo 'Photo resizing... ';

                $filename = FlickrImport::resize($imagePath,
                                                 $filename,
                                                 $conf['photo.resize.size'],
                                                 $conf['photo.resize.quality']);

                echo 'done.' . $endLine;
            }

            // download or make the photo thumbnail
            if ($conf['thumbs.size'] == 'thumbs' && isset($size['t']))
            {
                $photo->saveAs($thumbPath . 'thumb_' . $filename, Phlickr_Photo::SIZE_100PX, $size['t']['source']);
            }
            elseif ($conf['thumbs.size'] == 'square' && isset($size['s']))
            {
                $photo->saveAs($thumbPath . 'thumb_' . $filename, Phlickr_Photo::SIZE_75PX, $size['s']['source']);
            }
            else
            {
                // hack for createthumbnail which think we are in /admin/
                chdir('../../admin');
                function_exists('gd_info') && gd_info() != '' && createthumbnail($filename);
                chdir(dirname(__FILE__));
            }

            // check to append a photo link in the description
            if ($conf['photo.link'] == 'yes' && strpos($conf['photo.link.format'], '%s') !== false)
            {
                if ($body != '') $body .= "\n";

                $body .= sprintf($conf['photo.link.format'],
                             sprintf('<a href="%s">%s</a>', $link, $conf['photo.link.text']));
            }

            // register the photo in pixelpost
            FlickrImport::addPhoto($photo->getId(), array(
                'date'     => (($conf['photo.date'] == 'taken') ? $date : $post),
                'head'     => $head,
                'body'     => $body,
                'image'    => $filename,
                'altHead'  => $head,
                'altBody'  => $body,
                'comments' => '',
                'exifs'    => $exif,
            ));
        } // end register photo

        echo 'Check if photo ' . $photo->getId() . ' exists in photoset ' . $photoset->getTitle() . '... ';

        flush();

        // retreive photo and photoset ID in pixelpost
        $photosetId = FlickrImport::getPhotoset($photoset->getId());
        $photoId    = FlickrImport::getPhoto($photo->getId());

        // save the photo tags
        save_tags_new($tags, $photoId);

        // check if photo is in the photoset
        if (FlickrImport::isInPhotoset($photoId, $photosetId))
        {
            echo 'Yes !' . $endLine;
        }
        else
        {
            echo 'No, add it !' . $endLine;
            FlickrImport::addInPhotoset($photoId, $photosetId);
        }

        // retreive or not the photo comment
        if ($conf['comments'] == 'yes')
        {
            $comments = Phlickr_CommentList::getCommentList($api, $photo->getId());

            echo 'Check the photo comments : ' . $comments->getCount() . ' comment(s)' . $endLine;

            $added = 0;

            // for each photo comment
            foreach($comments->getComments() as $comment)
            {
                $id     = $comment->getId();

                // if is allready added go to the next comment
                if (FlickrImport::isComment($id, $photoId)) continue;

                $added++;

                $date    = date('Y-m-d H:i:s', $comment->getCreationDate());
                $name    = $comment->getAuthorName();
                $message = $comment->getComment();
                $author  = new Phlickr_User($api, $comment->getAuthorId());
                $url     = $author->buildUrl();

                // strip or not HTML tag in comment
                if ($conf['comments.html'] == 'no')
                {
                    $message = strip_tags($message);
                }

                $datas = array(
                    'id'      => $id,
                    'photo'   => $photoId,
                    'date'    => $date,
                    'message' => $message,
                    'name'    => $name,
                    'url'     => $url,
                );

                // publish or just add it in moderation list
                if ($conf['comments.publish'] == 'no')
                {
                    FlickrImport::addComment($datas);
                }
                else
                {
                    FlickrImport::addComment($datas, true);
                }
            } // end foreach comments

            echo $added . ' comment(s) added.' . $endLine;

        } // end if comments

        echo $endLine;
        flush();
        
    } // end foreach photos
} // end foreach photosets
