<?php
/**
 * FlickrImport
 *
 * Import your flickr stream into your pixelpost stream.
 *
 * IMPORTANT :
 *
 * This Pixelpost Addon include a modified part of Phlickr
 * produced by Andrew Morton <drewish@katherinehouse.com>
 * (@link http://sourceforge.net/projects/phlickr/)
 * which is under LGPL license.
 *
 * This Pixelpost addon is heavily inspired by Pixelpost Importr addon produced
 * by Christian Cueni <chrigu@trivialview.ch> (@link http://www.trivialview.ch)
 * which is under GPL license.
 *
 * REQUIREMENTS :
 *
 * - PHP CURL library installed
 * - SimpleXml library installed
 *
 * LICENCE :
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 *
 * @version 0.03
 * @author Alban Leroux <seza@paradoxal.org>
 * @see http://www.paradoxal.org/blog/
 * @license GPL License: http://www.gnu.org/copyleft/gpl.html
 */

// I'm in debug mode ?
if (isset($_GET['flickrimportdebug']))
{
    error_reporting(E_ALL);
    set_error_handler('FlickrImport_handler_error');
}

// Include common functions
require_once dirname(__FILE__) . '/FlickrImport/common.php';

// Connect to database
FlickrImport::mysqlConnect();

// Photos flickr's id table
FlickrImport::isInstalled() or FlickrImport::install();

// Check for update
FlickrImport::makeUpdate();

// register the Phlickr library
FlickrImport::registerPhlickrLibrary();

/**
 * Add-on definition
 */

// The addon définition
$addon_name           = FlickrImport::NAME;
$addon_version        = FlickrImport::VERSION;
$addon_description    = 'Import your flickr stream into your pixelpost stream.';
// The workspace. Where to activate the function inside index.php
$addon_workspace      = 'options';
$addon_workspace2     = 'image_deleted';
$addon_workspace3     = 'image_deleted';
// menu where the addon should appear in admin panel. in this case:
$addon_menu           = 'options';
$addon_menu2          = '';
// What would be the title of submenu of this addon:
$addon_admin_submenu  = FlickrImport::NAME;
$addon_admin_submenu2 = '';
// What is the function
$addon_function_name  = 'FlickrImport_options';
$addon_function_name2 = 'FlickrImport_deleteImg';

// Register methods to pixelpost
add_admin_functions($addon_function_name,  $addon_workspace,  $addon_menu,  $addon_admin_submenu);
add_admin_functions($addon_function_name2, $addon_workspace2, $addon_menu2, $addon_admin_submenu2);

/**
 * Methods Definition
 */

// error handler for debug mode
function FlickrImport_handler_error($number, $message, $file, $line, $context)
{
    printf('<p>[FLICKR_IMPORT ERROR REPRTING]<br /> %d : %s on file %s : %d </p>', $number, $message, $file, $line);
    ob_start();
    debug_print_backtrace();
    $bt = ob_get_contents();
    ob_end_clean();
    printf('<p>%s</p>', nl2br($bt));
}

// Forget the flickr_id of the deleted picture
function FlickrImport_deleteImg()
{
   return FlickrImport::delPhoto($_GET['imageid']);
}

// Used for making changes to the importr options
function FlickrImport_options()
{
    // addon name
    $me = FlickrImport::NAME;

    // get the configuration data
    $conf = FlickrImport::getOptions();

    // error message
    $eMessage = '';

    // if need to get the authentification token
    $doAuth   = ($conf['token'] == '');

    // the url to the config panel in admin
    $baseUrl  = $_SERVER['PHP_SELF'] . '?view=options&amp;optionsview=' . strtolower($me);

    // calc the web root of the photoblog
    $webUrl = substr($baseUrl, 0, strpos($baseUrl, 'admin/'));

    // load tha API and check the authentification token if necessary
    if ( ! $doAuth)
    {
        $api = FlickrImport::getApi($conf['token']);

        $api->getUserId();

        if ($api->isAuthValid() === false)
        {
            $doAuth = true;
            $eMessage = 'Your autorization is not longer valid, please make a new authorization.';
        }
    }

    // prepare or verify the authorization submission
    if ($doAuth)
    {
        // set the Phlickr API
        $api = FlickrImport::getApi();

        // get the frob
        $frob = (isset($_GET['ffrob']) 
              ? base64_decode(urldecode($_GET['ffrob']))
              : $api->requestFrob());

        // is user click on valid authentification
        if (isset($_GET['ffrob'])) try
        {
            // Try to get the auth token
            $api->setAuthTokenFromFrob($frob);

            // register the token
            $conf['token'] = $api->getAuthToken();

            if (FlickrImport::setOptions($conf))
                $doAuth = false;
            else
                $eMessage = 'Register Authorization Failed !';
        }
        catch(Exception $e)
        {
            $eMessage = $e->getMessage();
        }
    }

    if ($doAuth)
        // Load the authentification panel
        require dirname(__FILE__) . DIRECTORY_SEPARATOR . $me . DIRECTORY_SEPARATOR . 'auth_panel.php';
    else
        // load the configuration panel
        require dirname(__FILE__) . DIRECTORY_SEPARATOR . $me . DIRECTORY_SEPARATOR . 'conf_panel.php';
}